@@ -23,7 +23,8 @@ set_coef <- function(model, coefs, ...) {
 set_coef.default <- function(model, coefs, ...) {
     # in basic model classes coefficients are named vector
     # in ordinal::clm models, there are sometimes duplicates, so name matching doesn't work
-    if (all(names(model[["coefficients"]]) == names(coefs))) {
+    flag <- length(model[["coefficients"]]) == length(coefs) && all(names(model[["coefficients"]]) == names(coefs))
+    if (flag) {
         model[["coefficients"]] <- coefs
     } else {
         model[["coefficients"]][names(coefs)] <- coefs
