@@ -122,7 +122,7 @@ merge_by_rowid <- function(x, y) {
 
 # faster than all(x %in% 0:1)
 is_binary <- function(x) {
-    is.null(x) ||
-    (length(x) == 1 && x %in% 0:1) ||
-    isTRUE(min(x) == 0 && max(x) == 1 && data.table::uniqueN(x) == 2)
-}
+    isTRUE(checkmate::check_integerish(
+        x, null.ok = TRUE, upper = 1, lower = 0, any.missing = FALSE)
+    )
+}
\ No newline at end of file
